commit 60491d8e4a8ca557cfdb07029c5ebbde341c2c1d
Author: David G. Johnston <david.g.johnston@gmail.com>
Date:   Tue Apr 12 02:25:01 2022 +0000

    Fix a few instances of default database name descriptions.
    
    The default database name is just the user name, not the
    operating-system user name.
    
    In passing, the authentication error examples use the phrase
    "database user name" in a couple of locations.  The word
    database in both cases is both unusual and unnecesssary for
    understanding.
    
    Furthermore, it seems better to tell the reader the likely
    reason why the displayed database name happens to be a user name.

diff --git a/doc/src/sgml/client-auth.sgml b/doc/src/sgml/client-auth.sgml
index 142b0affcb..9b2323cde7 100644
--- a/doc/src/sgml/client-auth.sgml
+++ b/doc/src/sgml/client-auth.sgml
@@ -2218,7 +2218,7 @@ FATAL:  password authentication failed for user "andym"
 <programlisting>
 FATAL:  user "andym" does not exist
 </programlisting>
-    The indicated database user name was not found.
+    The indicated user name was not found.
    </para>
 
    <para>
@@ -2226,8 +2226,9 @@ FATAL:  user "andym" does not exist
 FATAL:  database "testdb" does not exist
 </programlisting>
     The database you are trying to connect to does not exist. Note that
-    if you do not specify a database name, it defaults to the database
-    user name, which might or might not be the right thing.
+    if the database name shown matches the user name you are connecting
+    as it is not by accident: the default database name is the
+    user name.
    </para>
 
    <tip>
diff --git a/doc/src/sgml/ref/psql-ref.sgml b/doc/src/sgml/ref/psql-ref.sgml
index 592356019b..c17fe7a9e5 100644
--- a/doc/src/sgml/ref/psql-ref.sgml
+++ b/doc/src/sgml/ref/psql-ref.sgml
@@ -657,7 +657,7 @@ EOF
     determined at compile time.
     Since the database server uses the same default, you will not have
     to specify the port in most cases. The default user name is your
-    operating-system user name, as is the default database name.
+    operating-system user name. The default database name is the resolved user name.
     Note that you cannot
     just connect to any database under any user name. Your database
     administrator should have informed you about your access rights.
